#! /bin/sh
#
# Copies properties files to ../classes. For resource bundles, creates
# creates the (for lack of a better phrase) "superclass" files. For
# example, if datavision_fr_FR.properties exists but
# datavision_fr.properties does not and no other datavision_fr_*.properties
# files exist, we copy datavision_fr_FR.properties to
# datavision_fr.properties.
#
# We also copy the default (US English) files.
#
# One more thing: we make sure the files have permission 644.
#

dv_dir=`dirname $0`/..
from=$dv_dir/jimm/properties
to=$dv_dir/classes

# Copy properties files for languages with more than one region.
for s in "pt_BR" "pt_PT" ; do
    for t in "datavision" "paper" "menu" ; do
	if [ -f $from/${t}_$s.properties ] ; then
	    cp $from/${t}_$s.properties $to
	fi
    done
done

# Fill in the holes by providing "superclass" properties files. For example,
# copy "datavision_bg_BG.properties" to "$to/datavision_bg.properties".
# For languages with more than one region (e.g., pt_PT and pt_BR), we
# pick a "dominant" version.
for s in "bg_BG" "de_DE" "es_MX" "fr_FR" "it_IT" "pt_PT" "ru_RU" "tr_TR" ; do
    for t in "datavision" "paper" "menu" ; do
	if [ -f $from/${t}_$s.properties ] ; then
	    cp $from/${t}_$s.properties $to/${t}_${s%_*}.properties
	fi
    done
done

# Copy the default (US English) files both to the default place and
# explicitly as en_US.
for s in "paper" "datavision" "menu" ; do
    cp $from/$s.properties $to
    cp $from/$s.properties $to/${s}_en_US.properties
done

# Change permissions.
chmod 644 $to/*.properties
