package jimm.datavision;
import java.util.*;

/**
 * Writes the element of a list of Writeable objects as XML.
 *
 * @see Writeable
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 */
public class ListWriter {

/**
 * Writes the elements of a list of Writeable objects as XML. An open tag
 * is written, then each object's <code>writeXML</code> method is called,
 * then a closing tag is written. If the list is empty, nothing at all gets
 * written.
 *
 * @param out the writer
 * @param list the collection of objects to write
 * @param name the XML tag name to use
 */
public static void writeList(IndentWriter out, Collection list, String name) {
    if (list.isEmpty())
	return;

    out.println();
    out.println("<" + name + ">");
    out.indent();
    for (Iterator iter = list.iterator(); iter.hasNext(); )
	((Writeable)iter.next()).writeXML(out);
    out.outdent();
    out.println("</" + name + ">");
}

}
