package jimm.datavision.gui;
import jimm.datavision.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * The main GUI report design window.
 *
 * @see Report
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 */
public class DesignWin extends Designer {

/**
 * Constructor. Reads the named report file or, if it's <code>null</code>,
 * creates a new, empty report.
 *
 * @param fileName an XML report file name; may be <code>null</code>
 */
public DesignWin(String fileName) {
    this(fileName, null);
}

/**
 * Constructor. Reads the named report file or, if it's <code>null</code>,
 * creates a new, empty report.
 *
 * @param fileName an XML report file name; may be <code>null</code>
 * @param databasePassword string to give to report; OK if it's
 * <code>null</code>
 */
public DesignWin(String fileName, String databasePassword) {
    super(fileName, databasePassword, null,
	  new JFrame(I18N.get("DesignWin.title")));

    frame.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);

    // Make sure we close the window when the user asks to close the window.
    // Update menu items when this window is activated.
    frame.addWindowListener(new WindowAdapter() {
	public void windowClosing(WindowEvent e) { maybeClose(); }
	public void windowActivated(WindowEvent e) { enableMenuItems(); }
    });

    frame.pack();
    frame.show();
}

/**
 * Builds the window components.
 */
protected void buildWindow() {
    super.buildWindow();

    // Set up key handling (also put inside section canvas?)
    frame.addKeyListener(new KeyAdapter() {
	public void keyPressed(KeyEvent e) {
	    if (!ignoreKeys) {
		int code = e.getKeyCode();
		if (code == KeyEvent.VK_BACK_SPACE
		    || code == KeyEvent.VK_DELETE)
		    deleteSelectedFields();
	    }
	}
	});
}

}
