package jimm.datavision.gui;
import jimm.datavision.*;
import jimm.datavision.gui.cmd.SuppressionProcEditCommand;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.event.ActionEvent;
import javax.swing.*;

/**
 * An edit dialog for suppression procs.
 *
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 * @see jimm.datavision.Formula
 * @see jimm.datavision.gui.cmd.SuppressionProcEditCommand
 */
public class SuppressionProcWin extends CodeEditorWin {

protected static final int CHECK_BOX_INDENT_WIDTH = 32;

protected SectionWidget sectionWidget;
protected JCheckBox hideCheckBox;

/**
 * Constructor.
 *
 * @param designer the window to which this dialog belongs
 * @param report the report
 * @param formula the formula whose text needs editing
 */
public SuppressionProcWin(Designer designer, SectionWidget sectionWidget) {
    super(designer, sectionWidget.getSection().getReport(),
	  sectionWidget.getSection().getSuppressionProc().getFormula()
	      .getEditableExpression(),
	  I18N.get("SuppressionProcWin.title"),
	  "SuppressionProcWin.error_unchanged",
	  "SuppressionProcWin.error_title");
    this.sectionWidget = sectionWidget;

    // Finish building the window
    hideCheckBox = new JCheckBox(I18N.get("SuppressionProcWin.always_hide"));
    hideCheckBox.setSelected(sectionWidget.getSection().getSuppressionProc()
			     .isHidden());
    enableEditBox();
    hideCheckBox.addActionListener(this);

    Box box = Box.createHorizontalBox();
    box.add(Box.createHorizontalStrut(CHECK_BOX_INDENT_WIDTH));
    box.add(hideCheckBox);

    getContentPane().add(box, BorderLayout.NORTH);
}

/**
 * Creates and executes a command that changes the formula's eval string.
 * If there is an error, the command is cancelled (never sent to the
 * design window).
 *
 * @param text the new eval string
 */
public void save(String text) {
    command = new SuppressionProcEditCommand(sectionWidget,
					     hideCheckBox.isSelected(), text);
}

/**
 * Listens for &quot;Always Hide&quot; actions; passes all others on to
 * our superclass.
 */
public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();
    if (I18N.get("SuppressionProcWin.always_hide").equals(cmd))
	enableEditBox();
    else
	super.actionPerformed(e);
}


/**
 * Enables or disables code editor box based on state of &quot;Always
 * Hide&quot; checkbox.
 */
protected void enableEditBox() {
    boolean hide = hideCheckBox.isSelected();
    codeField.setEditable(!hide);
    codeField.setBackground(hide ? Color.lightGray : Color.white);
}

}
