package jimm.datavision.gui.cmd;
import jimm.datavision.I18N;
import jimm.datavision.Report;
import jimm.datavision.Formula;

/**
 * A command for changing the report's startup formula's code text.
 *
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 * @see jimm.datavision.Report
 * @see jimm.datavision.Formula
 * @see jimm.datavision.gui.StartupScriptEditor
 */
public class ReportStartupScriptEditCommand extends CommandAdapter {

protected Report report;
protected String newExpression;
protected String oldExpression;

public ReportStartupScriptEditCommand(Report report, String expression) {
    super(I18N.get("ReportStartupScriptEditCommand.name"));
    this.report = report;
    newExpression = expression;
    Formula f = report.getStartFormula();
    oldExpression = f == null ? null : f.getExpression();
}

public void perform() {
    if (oldExpression == null)
	report.setStartFormula(new Formula(null, report, "", ""));
    report.getStartFormula().setEditableExpression(newExpression);
}

public void undo() {
    if (oldExpression == null)
	report.setStartFormula(null);
    else
	report.getStartFormula().setEditableExpression(oldExpression);
}

}
