package jimm.datavision.layout.pdf;
import java.awt.Font;
import java.util.HashSet;

/**
 * Holds a Java font and a PDF object id and knows how to print itself
 * as a PDF font description.
 *
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 */
class FontObj {

protected static final double LEADING_FACTOR = 1.1;

protected ObjectID id;
protected Font font;
protected double leading;
protected HashSet pages;

FontObj(Font f) {
    id = new ObjectID();
    font = f;
    pages = new HashSet();
    // Restrict leading to two significant digits
    leading = (double)((int)((font.getSize() * LEADING_FACTOR) * 100)) / 100.0;

}

ObjectID getID() { return id; }

Font getFont() { return font; }

String getName() { return "/F" + id.getID(); }

double getLeading() { return leading; }

void usedOnPage(Page p) { pages.add(p); }

boolean isUsedOnPage(Page p) { return pages.contains(p); }

void output(PDFLE pdf) {
    pdf.println(id + " obj");
    pdf.println("<<");
    pdf.println("/Type /Font");
    pdf.println("/Subtype /Type1");

    pdf.println("/Name " + getName());
    pdf.println("/BaseFont " + baseFont());
    pdf.println("/Encoding /MacRomanEncoding");

    pdf.println(">>");
    pdf.println("endobj");
}

String baseFont() {
    String name = font.getPSName();
    if (name.startsWith("Courier"))
	return "/Courier" + fontAttributes("Bold", "Oblique");
    else if (name.startsWith("Helvetica"))
	return "/Helvetica" + fontAttributes("Bold", "Oblique");
    else if (name.startsWith("Symbol"))
	return "/Symbol";
    else if (name.startsWith("ZapfDingbats"))
	return "/ZapfDingbats";
    else {
	String fontAttrs = fontAttributes("Bold", "Italic");
	return "/Times" + (fontAttrs.length() > 0 ? fontAttrs : "-Roman");
    }    
}

String fontAttributes(String bold, String italic) {
    if (font.isBold() && font.isItalic())
	return "-" + bold + italic;
    else if (font.isBold())
	return "-" + bold;
    else if (font.isItalic())
	return "-" + italic;
    else
	return "";
}

void outputResource(PDFLE pdf) {
    pdf.println(getName() + ' ' + id + " R");
}

void appendToBuf(StringBuffer buf, double size) {
    buf.append(getName());
    buf.append(' ');
    buf.append(size);
    buf.append(" Tf\n");
    buf.append(leading);
    buf.append(" TL\n");
}

}
