package jimm.datavision.layout.pdf;
import jimm.datavision.Format;
import java.awt.Font;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;

/**
 * Tracks the use of fonts, outputs the fonts, and gives their names
 * to those who request it politely.
 *
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 */
class FontTracker {

protected HashMap fontObjs;
protected FontObj defaultFontObj;
protected Page lastPageSeen;
protected Font lastFontUsed;

FontTracker() {
    fontObjs = new HashMap();

    Font defaultFont = Format.DEFAULT.getFont();
    defaultFontObj = new FontObj(defaultFont);
    fontObjs.put(defaultFont, defaultFontObj);
}

FontObj fontUsed(Page p, Font f) {
    Font standardSizeFont = f.getSize() == Format.DEFAULT.getSize()
	? f : f.deriveFont((float)Format.DEFAULT.getSize());
    FontObj fontObj = (FontObj)fontObjs.get(standardSizeFont);
    if (fontObj == null)
	fontObjs.put(standardSizeFont,
		     fontObj = new FontObj(standardSizeFont));

    fontObj.usedOnPage(p);
    lastFontUsed = f;
    lastPageSeen = p;

    return fontObj;
}

boolean lastFontUsedIs(Page p, Font f) {
    return p == lastPageSeen && f.equals(lastFontUsed);
}

// FontObj defaultFontObj() { return defaultFontObj; }

Iterator fontObjs() { return fontObjs.values().iterator(); }

Iterator fontObjsUsedBy(Page p) {
    ArrayList list = new ArrayList();
    for (Iterator iter = fontObjs.values().iterator(); iter.hasNext(); ) {
	FontObj f = (FontObj)iter.next();
	if (f.isUsedOnPage(p))
	    list.add(f);
    }
    return list.iterator();
}

}
