package jimm.datavision.layout.pdf;
import java.io.File;
import java.io.PrintWriter;
import java.util.*;

class XRef {

protected ArrayList indirObjs = new ArrayList();
protected long[] locList;
protected int maxID = 0;

int size() { return maxID + 1; }

void add(ObjectID objID) {
    indirObjs.add(objID);
    if (maxID < objID.getID())
	maxID = objID.getID();
}

void output(PrintWriter out) {
    buildLocList();

    out.println("xref");
    out.println("0 " + size());

    if (locList.length == 0) {
	String str = "0000000000 65535 f";
	if (File.separator.length() == 1)
	    str += ' ';		// If one-character line ending, add space
	out.println(str);
	return;
    }

    String firstSuffix = " 65535 f";
    String unusedSuffix = " 00001 f";
    String usedSuffix = " 00000 n";
    if (File.separator.length() == 1) {
	firstSuffix += ' ';	// If one-character line ending, add space
	unusedSuffix += ' ';
	usedSuffix += ' ';
    }

    for (int i = 0; i < locList.length; ++i) {
	long loc = locList[i];
	if (loc == -1) {	// unused
	    out.println(tenDigitNumber(nextUnused(i))
			+ (i == 0 ? firstSuffix : unusedSuffix));
	}
	else {
	    out.println(tenDigitNumber(loc) + usedSuffix);
	}
    }
}

protected void buildLocList() {
    locList = new long[size()];
    for (int i = 0; i < locList.length; ++i)
	locList[i] = -1;
    for (Iterator iter = indirObjs.iterator(); iter.hasNext(); ) {
	ObjectID objID = (ObjectID)iter.next();
	locList[objID.getID()] = objID.getLoc();
    }
}

protected int nextUnused(int i) {
    for (i += 1; i < locList.length; ++i)
	if (locList[i] == -1)
	    return i;
    return 0;
}

protected String tenDigitNumber(long l) {
    String str = "" + l;
    return "0000000000".substring(str.length()) + str;
}
}
