package jimm.datavision.source.charsep;
import jimm.datavision.*;
import jimm.datavision.source.Query;
import jimm.datavision.source.Column;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * A query used in character-separated file queries.
 *
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 * @see CharSepSource
 */
public class CharSepQuery extends Query {

protected ArrayList charSepCols;

public CharSepQuery(Report r) {
    super(r);
    charSepCols = new ArrayList();
}

void addColumn(Column col) {
    charSepCols.add(col);
}

/**
 * Clears our cache of columns handed to us by the char sep data source.
 * This is called by the data source before it hands us a new set of
 * metadata.
 */
void clearColumns() {
    charSepCols.clear();
}

public void findColumnsUsed() {
    columns.clear();
    usercols.clear();
    columns.addAll(charSepCols);
    report.withFieldsDo(new FieldWalker() {
	public void step(Field f) {
	    if (f instanceof FormulaField) {
		FormulaField ff = (FormulaField)f;
		for (Iterator iter = ff.userColumnsUsed().iterator();
		     iter.hasNext(); )
		{
		    UserColumn uc = (UserColumn)iter.next();
		    if (!usercols.contains(uc)) usercols.add(uc);
		}
	    }
	    else if (f instanceof UserColumnField) {
		UserColumn uc = ((UserColumnField)f).getUserColumn();
		if (!usercols.contains(uc)) usercols.add(uc);
	    }
	}
	});
}

}
