package jimm.datavision.source.charsep;
import java.util.*;

/**
 * Parses delimited data. Handles quotes and embedded delimiters.
 *
 * @author Jim Menard, <a href="mailto:jimm@io.com">jimm@io.com</a>
 */
public class DelimParser {

/**
 * Given a single-character delimiter and a line of delimiter-separated data,
 * return an array of column data. Handles delimiters and quotes within the
 * data just as they are generated by Excel comma- and tab-separated files.
 *
 * @param delimiter the character delimiting columns of text (often comma
 * or tab)
 * @param line the text to parse
 * @return a <code>ArrayList</code> of strings; return <code>null</code> if
 * line is <code>null</code>
 */
public static ArrayList parse(char delimiter, String line) {
    if (line == null)
	return null;

    ArrayList columns = new ArrayList();
    boolean insideQuotes = false;
    int numQuotesSeen = 0;
    StringBuffer buf = new StringBuffer();

    char c;
    char prevChar = '\0';
    for (int i = 0; i < line.length(); ++i) {
	c = line.charAt(i);

	// Delimiter character
	if (c == delimiter) {
	    // Normal delimiter
	    if (!insideQuotes) {
		columns.add(buf.toString());
		buf = new StringBuffer();
	    }
	    // Inside quoted column
	    else {
		// Delimiter at end of quoted column data
		if (numQuotesSeen == 1) {
		    insideQuotes = false;
		    columns.add(buf.toString());
		    buf = new StringBuffer();
		}
		// Delimiter inside quoted column
		else
		    buf.append(delimiter);
	    }
	}
	// Quote character
	else if (c == '"') {
	    if (!insideQuotes) { // Start of quoted column
		insideQuotes = true;
		numQuotesSeen = 0;
	    }
	    else if (insideQuotes) { // Inside quoted column
		if (numQuotesSeen == 1) { // This is second of doubled quotes
		    buf.append(c);
		    numQuotesSeen = 0;
		}
		else
		    numQuotesSeen = 1;
	    }
	}
	// Any other old char
	else {
	    numQuotesSeen = 0;
	    buf.append(c);
	}

	prevChar = c;
    }

    if (buf.length() > 0 || prevChar == delimiter)
	columns.add(buf.toString());
    return columns;
}

}
