package jimm.datavision.test;
import jimm.datavision.source.charsep.DelimParser;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;
import java.util.ArrayList;

public class DelimParserTest extends TestCase {

protected static final String TEST_FILE = "parser_test_file";
protected static final String[][] ANSWERS = {
    {"row one", "\"nasty:,\"", "has, comma", "has \"quotes\"",
     "has 'single quotes'"},
    {"has \"comma, in quotes\"", "has 'comma, in single quotes'",
     "quotes \",\" surrounding", "", ""},
    {"odd \"number of\" double \"quotes", "two, yes two, commas",
     "two, \"commas, second\" in quotes", "", ""},
    {"simple", "row", "internal \"quote", "", ""}
};
protected static final String[] DATA = {
    "row one,\"\"\"nasty:,\"\"\",\"has, comma\",\"has \"\"quotes\"\"\",has 'single quotes'",
    "\"has \"\"comma, in quotes\"\"\",\"has 'comma, in single quotes'\",\"quotes \"\",\"\" surrounding\",,",
    "\"odd \"\"number of\"\" double \"\"quotes\",\"two, yes two, commas\",\"two, \"\"commas, second\"\" in quotes\",,",
    "simple,row,\"internal \"\"quote\",,"
};


public static Test suite() {
    return new TestSuite(DelimParserTest.class);
}

public DelimParserTest(String name) {
    super(name);
}

protected void sepTest(String[] answer, String data) {
    ArrayList parsed = DelimParser.parse(',', data);
    assertNotNull("should not have null array", parsed);
    assertTrue("answer length (" + answer.length
	       + ") not same length as parsed data size (" + parsed.size()
	       + ")",
	       answer.length == parsed.size());
    for (int i = 0; i < answer.length; ++i)
	assertEquals(answer[i], parsed.get(i));
}

public void testParser() {
    for (int i = 0; i < ANSWERS.length; ++i)
	sepTest(ANSWERS[i], DATA[i]);
}

public static void main(String[] args) {
    junit.textui.TestRunner.run(suite());
}

}
